<?php
/**
 * Product Visibility by Country for WooCommerce - General Section Settings
 *
 * @version 1.1.5
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_PVBC_Settings_General' ) ) :

class Alg_WC_PVBC_Settings_General extends Alg_WC_PVBC_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'product-visibility-by-country-for-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_settings.
	 *
	 * @version 1.1.5
	 * @since   1.0.0
	 */
	function get_settings() {
		$main_settings = array(
			array(
				'title'    => __( 'Product Visibility by Country Options', 'product-visibility-by-country-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_pvbc_options',
				'desc'     => sprintf( __( 'Please note that if you have any <strong>caching</strong> plugins installed, you will need to set "Geolocate (with caching support)" option for "Default customer location" in %s.', 'product-visibility-by-country-for-woocommerce' ),
					'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=general' ) . '">WooCommerce > Settings > General</a>' ),
			),
			array(
				'title'    => __( 'Product Visibility by Country', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'product-visibility-by-country-for-woocommerce' ) . '</strong>',
				'id'       => 'alg_wc_pvbc_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_pvbc_options',
			),
		);
		$general_settings = array(
			array(
				'title'    => __( 'General Options', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => '<p style="background-color: #ffffff; padding: 10px; font-weight: bold;">' .
					__( 'To set countries for each product, check "Product Visibility by Country" meta box on each product\'s edit page.', 'product-visibility-by-country-for-woocommerce' ) .
				'</p>',
				'type'     => 'title',
				'id'       => 'alg_wc_pvbc_general_options',
			),
			array(
				'title'    => __( 'Hide catalog visibility', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'This will hide selected products in shop and search results. However product still will be accessible via direct link.', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_visibility',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Make non-purchasable', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'This will make selected products non-purchasable (i.e. product can\'t be added to the cart).', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_purchasable',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Modify query', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'This will hide selected products completely (including direct link).', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_query',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'desc_tip' => __( 'Optionally set URL for hidden products to redirect to (i.e. different from 404 page).', 'product-visibility-by-country-for-woocommerce' ) . ' ' .
					sprintf( __( 'Enter full URL (i.e. with %s).', 'product-visibility-by-country-for-woocommerce' ), '<em>http(s)://</em>' ) . ' ' .
					__( '"Modify query" option must be enabled.', 'product-visibility-by-country-for-woocommerce' ) . ' ' .
					__( 'Ignored if empty.', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Redirect URL', 'product-visibility-by-country-for-woocommerce' ) .
					apply_filters( 'alg_wc_pvbc', '<br>' .
						sprintf( 'You will need <a href="%s" target="_blank">Product Visibility by Country for WooCommerce Pro</a> plugin to customize redirect URL.',
							'https://wpfactory.com/item/product-visibility-by-country-for-woocommerce/' ), 'settings' ),
				'id'       => 'alg_wc_pvbc_query_redirect_url',
				'default'  => '',
				'type'     => 'text',
				'css'      => 'width:100%',
				'custom_attributes' => apply_filters( 'alg_wc_pvbc', array( 'readonly' => 'readonly' ), 'settings' ),
			),
			array(
				'desc_tip' => __( 'Enable this if you are still seeing hidden products in "Products" widgets.', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Modify widget query', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_query_widget',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Hide price', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'This will hide prices for selected products.', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Hide', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_hide_price',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'id'       => 'alg_wc_pvbc_hide_price_content',
				'desc'     => __( 'Content', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'Set this if you wish to replace price with some message. Can be empty.', 'product-visibility-by-country-for-woocommerce' ) . ' ' .
					__( 'You can use HTML and/or shortcodes here.', 'product-visibility-by-country-for-woocommerce' ),
				'default'  => '',
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_pvbc_raw' => true,
			),
			array(
				'title'    => __( 'Info on single product page', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'This will output message on single product page for selected products.', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Add', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_info_on_single_product',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'id'       => 'alg_wc_pvbc_info_on_single_product_content',
				'desc'     => __( 'Content', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'product-visibility-by-country-for-woocommerce' ),
				'default'  => '<p><strong>' . __( 'The product is not available in your country.', 'product-visibility-by-country-for-woocommerce' ) . '</strong></p>',
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_pvbc_raw' => true,
			),
			array(
				'title'    => __( 'Info on archives', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'This will output message on archives for selected products.', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Add', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_info_on_loop',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'id'       => 'alg_wc_pvbc_info_on_loop_content',
				'desc'     => __( 'Content', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'product-visibility-by-country-for-woocommerce' ),
				'default'  => '<p><strong>' . __( 'The product is not available in your country.', 'product-visibility-by-country-for-woocommerce' ) . '</strong></p>',
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_pvbc_raw' => true,
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_pvbc_general_options',
			),
		);
		$product_terms_settings = array(
			array(
				'title'    => __( 'Product Terms Options', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => '<p style="background-color: #ffffff; padding: 10px; font-weight: bold;">' .
					sprintf( __( 'When enabled, this will add new options to category and tag edit pages in "%s" and "%s".', 'product-visibility-by-country-for-woocommerce' ),
					sprintf( '<a href="%s">%s > %s</a> > %s',
						admin_url( 'edit-tags.php?taxonomy=product_cat&post_type=product' ),
						__( 'Products', 'product-visibility-by-country-for-woocommerce' ),
						__( 'Categories', 'product-visibility-by-country-for-woocommerce' ),
						__( 'Category', 'product-visibility-by-country-for-woocommerce' )
					),
					sprintf( '<a href="%s">%s > %s</a> > %s',
						admin_url( 'edit-tags.php?taxonomy=product_tag&post_type=product' ),
						__( 'Products', 'product-visibility-by-country-for-woocommerce' ),
						__( 'Tags', 'product-visibility-by-country-for-woocommerce' ),
						__( 'Tag', 'product-visibility-by-country-for-woocommerce' )
					) ) .
				'</p>',
				'type'     => 'title',
				'id'       => 'alg_wc_pvbc_product_terms_options',
			),
			array(
				'title'    => __( 'Hide product terms', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'Enable this if you want to be able to hide product <strong>categories</strong> and <strong>tags</strong>.', 'product-visibility-by-country-for-woocommerce' ) .
					apply_filters( 'alg_wc_pvbc', '<br>' .
						sprintf( 'You will need <a href="%s" target="_blank">Product Visibility by Country for WooCommerce Pro</a> plugin to hide product terms.',
							'https://wpfactory.com/item/product-visibility-by-country-for-woocommerce/' ), 'settings' ),
				'desc'     => __( 'Enable', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_product_terms',
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pvbc', array( 'disabled' => 'disabled' ), 'settings' ),
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_pvbc_product_terms_options',
			),
		);
		$admin_settings = array(
			array(
				'title'    => __( 'Admin Options', 'product-visibility-by-country-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_pvbc_admin_options',
			),
			array(
				'title'    => __( 'Admin products list column', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'This will add "Countries" column to the admin products list.', 'product-visibility-by-country-for-woocommerce' ),
				'desc'     => __( 'Add', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_add_column_visible_countries',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Select box type', 'product-visibility-by-country-for-woocommerce' ),
				'desc_tip' => __( 'Select box type on product\'s edit page and on term\'s edit page.', 'product-visibility-by-country-for-woocommerce' ),
				'id'       => 'alg_wc_pvbc_select_box_type',
				'default'  => 'chosen_select',
				'type'     => 'select',
				'class'    => 'wc-enhanced-select',
				'options'  => array(
					'standard'      => __( 'Standard', 'product-visibility-by-country-for-woocommerce' ),
					'chosen_select' => __( 'Chosen select', 'product-visibility-by-country-for-woocommerce' ),
				),
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_pvbc_admin_options',
			),
		);
		return array_merge( $main_settings, $general_settings, $product_terms_settings, $admin_settings );
	}

}

endif;

return new Alg_WC_PVBC_Settings_General();
